Index: /trunk/src/VBox/Runtime/r0drv/linux/time-r0drv-linux.c
===================================================================
--- /trunk/src/VBox/Runtime/r0drv/linux/time-r0drv-linux.c	(revision 9239)
+++ /trunk/src/VBox/Runtime/r0drv/linux/time-r0drv-linux.c	(revision 9240)
@@ -44,10 +44,10 @@
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 16)
     /*
      * Use ktime_get, this is also what clock_gettime(CLOCK_MONOTONIC,) is using.
      */
-    ktime_t Kt = ktime_get();
-    struct timespec Ts = ktime_to_timespec(Kt);
-    uint64_t u64 = Ts.tv_sec * UINT64_C(1000000000)
-                 + Ts.tv_nsec;
+    uint64_t u64;
+    struct timespec Ts;
+    ktime_get_ts(&Ts);
+    u64 = Ts.tv_sec * UINT64_C(1000000000) + Ts.tv_nsec;
     return u64;
 
@@ -44,10 +44,10 @@
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 16)
     /*
-     * Use ktime_get, this is also what clock_gettime(CLOCK_MONOTONIC,) is using.
+     * Use ktime_get_ts, this is also what clock_gettime(CLOCK_MONOTONIC,) is using.
      */
